(tutorials)=

# Tutorials

The tutorials in this section are automatically executed with every change of
the code to make sure that they are always up-to-date. As a result, they are
designed to require only a relatively small amount of computation time; when
using `jaxoplanet` for real problems you will probably find that your run
times are longer.

To execute a tutorial on your own, you can click on the buttons at the top right
or this page to launch the notebook using [Binder](https://mybinder.org),
[Colab](https://colab.research.google.com), or download the `.ipynb` file
directly.

## Introductory Topics

```{toctree}
:maxdepth: 1

tutorials/getting-started.ipynb
tutorials/autodiff.ipynb
tutorials/transit.ipynb
tutorials/rv.ipynb
tutorials/starry.ipynb
tutorials/core-from-scratch.ipynb
```
